aboutsummaryrefslogtreecommitdiffhomepage
path: root/tools/gpu/vk/VkTestContext.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'tools/gpu/vk/VkTestContext.cpp')
-rw-r--r--tools/gpu/vk/VkTestContext.cpp5
1 files changed, 4 insertions, 1 deletions
diff --git a/tools/gpu/vk/VkTestContext.cpp b/tools/gpu/vk/VkTestContext.cpp
index 44be9fd242..f6849e4484 100644
--- a/tools/gpu/vk/VkTestContext.cpp
+++ b/tools/gpu/vk/VkTestContext.cpp
@@ -10,7 +10,7 @@
#ifdef SK_VULKAN
namespace {
// TODO: Implement fence syncs and swap buffers
class VkTestContextImpl : public sk_gpu_test::VkTestContext {
public:
VkTestContextImpl()
@@ -20,6 +20,9 @@ public:
void testAbandon() override {}
+ void submit() override {}
+ void finish() override {}
+
protected:
void teardown() override { fVk.reset(nullptr); }
@@ -10,7 +10,7 @@
#ifdef SK_VULKAN
namespace {
-// TODO: Implement fence syncs and swap buffers
+// TODO: Implement fence syncs, swap buffers, submit, and flush
class VkTestContextImpl : public sk_gpu_test::VkTestContext {
public: